@@ -15,8 +15,8 @@ set -e
 # sh 3.4/debian/orig-tar.sh RELEASE_34 rc1
 
 SVN_BASE_URL=http://llvm.org/svn/llvm-project/
-MAJOR_VERSION=4.0
-CURRENT_VERSION=4.0 # Should be changed to 3.5.1 later
+MAJOR_VERSION=5.0
+CURRENT_VERSION=5.0 # Should be changed to 3.5.1 later
 
 if test -n "$1"; then
 # http://llvm.org/svn/llvm-project/{cfe,llvm,compiler-rt,...}/branches/google/stable/
@@ -77,8 +77,10 @@ checkout_sources() {
     if test -d $DEST; then
         cd $DEST
         if test -n "$BRANCH"; then
+            svn cleanup
             svn up
         else
+            svn cleanup
             svn up -r $REVISION
         fi
         cd ..
@@ -125,28 +127,28 @@ mkdir -p $SVN_ARCHIVES
 # LLVM
 LLVM_TARGET=$FULL_VERSION
 checkout_sources llvm $(get_svn_url llvm $BRANCH $TAG) $LLVM_TARGET "$BRANCH" $REVISION
-tar jcvf $FULL_VERSION.orig.tar.bz2 $LLVM_TARGET
+tar jcf $FULL_VERSION.orig.tar.bz2 $LLVM_TARGET
 rm -rf $LLVM_TARGET
 
 
 # Clang
 CLANG_TARGET=clang_$VERSION
 checkout_sources clang $(get_svn_url cfe $BRANCH $TAG) $CLANG_TARGET "$BRANCH" $REVISION
-tar jcvf $FULL_VERSION.orig-clang.tar.bz2 $CLANG_TARGET
+tar jcf $FULL_VERSION.orig-clang.tar.bz2 $CLANG_TARGET
 rm -rf $CLANG_TARGET
 
 
 # Clang extra
 CLANG_TARGET=clang-tools-extra_$VERSION
 checkout_sources clang-tools-extra $(get_svn_url clang-tools-extra $BRANCH $TAG) $CLANG_TARGET "$BRANCH" $REVISION
-tar jcvf $FULL_VERSION.orig-clang-tools-extra.tar.bz2 $CLANG_TARGET
+tar jcf $FULL_VERSION.orig-clang-tools-extra.tar.bz2 $CLANG_TARGET
 rm -rf $CLANG_TARGET
 
 # Compiler-rt
 COMPILER_RT_TARGET=compiler-rt_$VERSION
 checkout_sources compiler-rt $(get_svn_url compiler-rt $BRANCH $TAG) $COMPILER_RT_TARGET "$BRANCH" $REVISION
 #$SVN_CMD $(get_svn_url compiler-rt $BRANCH $TAG) $COMPILER_RT_TARGET
-tar jcvf $FULL_VERSION.orig-compiler-rt.tar.bz2 $COMPILER_RT_TARGET
+tar jcf $FULL_VERSION.orig-compiler-rt.tar.bz2 $COMPILER_RT_TARGET
 rm -rf $COMPILER_RT_TARGET
 
 # Polly
@@ -154,7 +156,7 @@ POLLY_TARGET=polly_$VERSION
 checkout_sources polly $(get_svn_url polly $BRANCH $TAG) $POLLY_TARGET "$BRANCH" $REVISION
 #$SVN_CMD $(get_svn_url polly $BRANCH $TAG) $POLLY_TARGET
 rm -rf $POLLY_TARGET/www $POLLY_TARGET/autoconf/config.sub $POLLY_TARGET/autoconf/config.guess
-tar jcvf $FULL_VERSION.orig-polly.tar.bz2 $POLLY_TARGET
+tar jcf $FULL_VERSION.orig-polly.tar.bz2 $POLLY_TARGET
 rm -rf $POLLY_TARGET
 
 # LLD
@@ -162,7 +164,7 @@ LLD_TARGET=lld_$VERSION
 checkout_sources lld $(get_svn_url lld $BRANCH $TAG) $LLD_TARGET "$BRANCH" $REVISION
 #$SVN_CMD $(get_svn_url lld $BRANCH $TAG) $LLD_TARGET
 rm -rf $LLD_TARGET/www/
-tar jcvf $FULL_VERSION.orig-lld.tar.bz2 $LLD_TARGET
+tar jcf $FULL_VERSION.orig-lld.tar.bz2 $LLD_TARGET
 rm -rf $LLD_TARGET
 
 # LLDB
@@ -170,7 +172,7 @@ LLDB_TARGET=lldb_$VERSION
 checkout_sources lldb $(get_svn_url lldb $BRANCH $TAG) $LLDB_TARGET "$BRANCH" $REVISION
 #$SVN_CMD $(get_svn_url lldb $BRANCH $TAG) $LLDB_TARGET
 rm -rf $LLDB_TARGET/www/
-tar jcvf $FULL_VERSION.orig-lldb.tar.bz2 $LLDB_TARGET
+tar jcf $FULL_VERSION.orig-lldb.tar.bz2 $LLDB_TARGET
 rm -rf $LLDB_TARGET
 
 PATH_DEBIAN="$(pwd)/$(dirname $0)/../"
